@@ -2,11 +2,11 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: tagrubricannotation.py 51587 2008-08-31 18:00:21Z cray $
+$Id: tagrubricannotation.py 51876 2008-10-20 18:01:50Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51587 $"
+__version__ = "$Revision: 51876 $"
 
 from persistent import Persistent
 from zope.interface import Interface
@@ -20,9 +20,11 @@ class TagRubricAnnotation(Persistent) :
     __parent__=None
     __name__= "++annotations++" + tagrubricannotationkey
 
-    # See tagrubricannotation.interfaces.ITagRubricAnnotation
-    suffixes = ''
-    keyword = []
-    area = []
-    gender = []
-    wikiword=''    
\ No newline at end of file
+    def __init__(self,*kv,**kw) :
+        super(TagRubricAnnotation,self).__init__(*kv,**kw)
+        self.tags = set([])
+        self.tags_added = ()
+
+    tags = set([])
+    tags_added = ()
+    
\ No newline at end of file
