@@ -3,7 +3,7 @@
 """Vocabulary for tagrubricannotation used to get values from
 IIndexValues 'tags' utility
 
-$Id: tagvocabulary.py 51587 2008-08-31 18:00:21Z cray $
+$Id: tagvocabulary.py 51876 2008-10-20 18:01:50Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
@@ -14,7 +14,9 @@ from zope.interface import implements
 from zope.schema.interfaces import  IContextSourceBinder
 from zc.catalog.interfaces import IIndexValues
 from zope.interface import implements, alsoProvides
-from zope.schema.vocabulary import SimpleVocabulary
+#from zope.schema.vocabulary import SimpleVocabulary,SimpleTerm
+from ng.lib.simplevocabulary import SimpleVocabulary
+
 
 class TagVocabulary(object) :
     implements(IContextSourceBinder)
@@ -24,9 +26,10 @@ class TagVocabulary(object) :
         
     def __call__(self,context) :
         vocabulary = SimpleVocabulary.fromValues(
-          sorted(
-            getUtility(IIndexValues,context=context,name=self.name).values()
-            )
-          )
+          [ x for x in sorted(
+                getUtility(IIndexValues,context=context,name=self.name).values()
+                ) 
+            ]
+          ) 
         return vocabulary
 
